==> hinemos_src-3.2.2.tar.gz: HinemosManager/src_port/com/clustercontrol/port/factory/SelectMonitorPort.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.port.factory;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.port.bean.PortCheckInfo;
import com.clustercontrol.port.ejb.entity.MonitorPortInfoLocal;
import com.clustercontrol.port.ejb.entity.MonitorPortInfoPK;
import com.clustercontrol.port.ejb.entity.MonitorPortInfoUtil;

/**
 * port監視判定情報検索クラス
 *
 * @version 2.4.0
 * @since 2.4.0
 */
public class SelectMonitorPort extends SelectMonitor{
	
	protected static Log m_log = LogFactory.getLog( SelectMonitorPort.class );

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	public PortCheckInfo getPortCheckInfo() throws FinderException, NamingException{
		
		// port監視情報を取得
		MonitorPortInfoPK pk = new MonitorPortInfoPK(m_monitorId, m_monitorTypeId);
		MonitorPortInfoLocal portLocal = MonitorPortInfoUtil.getLocalHome().findByPrimaryKey(pk);
		
		PortCheckInfo port = new PortCheckInfo();
		port.setMonitorTypeId(m_monitorTypeId);
		port.setMonitorId(m_monitorId);
		port.setPortNo(portLocal.getPortNo());  //ポート番号
		port.setRunCount(portLocal.getRunCount());
		port.setRunInterval(portLocal.getRunInterval());
		port.setTimeout(portLocal.getTimeout());
		port.setServiceId(portLocal.getServiceId());
		
		return port;
	}
}

==> hinemos_src-4.0.3.tar.gz: HinemosManager/src_port/com/clustercontrol/port/factory/SelectMonitorPort.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.port.factory;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.port.bean.PortCheckInfo;
import com.clustercontrol.port.ejb.entity.MonitorPortInfoLocal;
import com.clustercontrol.port.ejb.entity.MonitorPortInfoUtil;

/**
 * port監視判定情報検索クラス
 *
 * @version 4.0.0
 * @since 2.4.0
 */
public class SelectMonitorPort extends SelectMonitor{

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	protected PortCheckInfo getPortCheckInfo() throws FinderException, NamingException{

		// port監視情報を取得
		MonitorPortInfoLocal portLocal = MonitorPortInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);

		PortCheckInfo port = new PortCheckInfo();
		port.setMonitorTypeId(m_monitorTypeId);
		port.setMonitorId(m_monitorId);
		port.setPortNo(portLocal.getPortNo());  //ポート番号
		port.setRunCount(portLocal.getRunCount());
		port.setRunInterval(portLocal.getRunInterval());
		port.setTimeout(portLocal.getTimeout());
		port.setServiceId(portLocal.getServiceId());

		return port;
	}
}
